# FuzzyDateV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**year** | [**YearV20**](YearV20.md) |  | 
**month** | [**MonthV20**](MonthV20.md) |  | [optional] 
**day** | [**DayV20**](DayV20.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

